<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>应用程序选择器</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>选择打开此类文件的默认应用程序:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>支持打开 JPEG 的应用程序</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>新子项</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="191"/>
        <location filename="../applicationchooser.cpp" line="217"/>
        <source>Other applications</source>
        <translation>其它应用程序</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="147"/>
        <source>Web browsers</source>
        <translation>网页浏览器</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="152"/>
        <source>Email clients</source>
        <translation>电子邮件客户端</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="157"/>
        <source>File managers</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="193"/>
        <location filename="../applicationchooser.cpp" line="219"/>
        <source>Other applications that handle %1</source>
        <translation>支持打开 %1 的其它应用程序</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="194"/>
        <location filename="../applicationchooser.cpp" line="220"/>
        <source>Applications that handle %1</source>
        <translation>支持打开 %1 的应用程序</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="305"/>
        <source>No applications found</source>
        <translation>未找到任何应用程序</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="310"/>
        <source>No more applications found</source>
        <translation>找不到更多的应用程序</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="271"/>
        <location filename="../mimetypeviewer.cpp" line="290"/>
        <location filename="../mimetypeviewer.cpp" line="309"/>
        <source>Change...</source>
        <translation>更改...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="275"/>
        <location filename="../mimetypeviewer.cpp" line="294"/>
        <location filename="../mimetypeviewer.cpp" line="313"/>
        <location filename="../mimetypeviewer.cpp" line="327"/>
        <location filename="../mimetypeviewer.cpp" line="388"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="276"/>
        <location filename="../mimetypeviewer.cpp" line="295"/>
        <location filename="../mimetypeviewer.cpp" line="314"/>
        <source>Choose...</source>
        <translation>选择...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="384"/>
        <source>&amp;Change...</source>
        <translation>更改(&amp;C)...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="389"/>
        <source>&amp;Choose...</source>
        <translation>选择(&amp;C)...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>文件关联</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="30"/>
        <source>Associations</source>
        <translation>关联</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="206"/>
        <source>Default application</source>
        <translation>默认应用程序</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="271"/>
        <source>&amp;Choose...</source>
        <translation>选择(&amp;C)...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="305"/>
        <source>Default Applications</source>
        <translation>默认应用程序</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="347"/>
        <source>Web Browser</source>
        <translation>网页浏览器</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="412"/>
        <location filename="../mimetypeviewer.ui" line="487"/>
        <location filename="../mimetypeviewer.ui" line="562"/>
        <source>Choose...</source>
        <translation>选择...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="422"/>
        <source>Email Client</source>
        <translation>电子邮件客户端</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="497"/>
        <source>File Manager</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="255"/>
        <location filename="../mimetypeviewer.ui" line="396"/>
        <location filename="../mimetypeviewer.ui" line="471"/>
        <location filename="../mimetypeviewer.ui" line="546"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="187"/>
        <source>Patterns</source>
        <translation>后缀名</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="193"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="146"/>
        <source>MIME type</source>
        <translation>MIME 类型</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="164"/>
        <location filename="../mimetypeviewer.ui" line="248"/>
        <location filename="../mimetypeviewer.ui" line="389"/>
        <location filename="../mimetypeviewer.ui" line="464"/>
        <location filename="../mimetypeviewer.ui" line="539"/>
        <source>Icon</source>
        <translation>图标</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="171"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
</context>
</TS>
